import 'package:get/get.dart';
import 'dart:io'; 
import 'package:flutter/material.dart';
import 'package:wowit/common.dart';
import 'dart:async';  
import 'package:wowit/firebaseService.dart';
import 'package:connectivity/connectivity.dart';
import 'package:wowit/message.dart'; 


class ConnectActivityController extends GetxController {
  bool isOnline = true; 
  setIsOnline(bool _isOnline) {
    this.isOnline = _isOnline;
    update();
  }
}

class WidgetConnectivity extends StatefulWidget {
  @override
  State<StatefulWidget> createState() => _WidgetConnectivity();
}

class _WidgetConnectivity extends State<WidgetConnectivity> {
  Map mapSource = {
    ConnectivityResult.none: false,
  };
  MyConnectivity _connectivity = MyConnectivity.instance;

  @override
  void initState() {
    super.initState();
    Get.put(ConnectActivityController());
    _connectivity.initialise();
    _connectivity.myStream.listen((source) {
      setState(() => mapSource = source);
    });
  }

  @override
  Widget build(BuildContext context) {
    ConnectActivityController controller =
        Get.find<ConnectActivityController>();
    if (controller == null) {
      controller = Get.put(ConnectActivityController());
    }
    return GetBuilder(
      init: controller,
      builder: (ConnectActivityController controller) {
        return Container(
          height: controller.isOnline ? 0 : 20,
          child: Container(
              color: Color(0xff103C61),
              width: MediaQuery.of(context).size.width,
              child: Center(
                child: Text(Message.getMessage('NO_INTERNET_CONNECTION'),
                    style: TextStyle(color: Colors.white, fontSize: 10)),
              )),
        );
      },
    );
  }

  @override
  void dispose() {
    _connectivity.disposeStream();
    super.dispose();
  }
}

class MyConnectivity {
  MyConnectivity._internal();

  static final MyConnectivity _instance = MyConnectivity._internal();

  static MyConnectivity get instance => _instance;

  Connectivity connectivity = Connectivity();

  StreamController controller = StreamController.broadcast();

  Stream get myStream => controller.stream;

  void initialise() async {
    var result = await connectivity.checkConnectivity();
    _checkStatus(result);
    connectivity.onConnectivityChanged.listen((connectivityResult) {
      _checkStatus(connectivityResult);
    });
  }

  void _checkStatus(ConnectivityResult connectivityResult) async {
    bool isOnline = false;
    try {
      final result = await InternetAddress.lookup('google.com');
      if (connectivityResult != ConnectivityResult.none &&
          result.isNotEmpty &&
          result[0].rawAddress.isNotEmpty) {
        print('checkInternet');
        isOnline = true;
        try {} catch (e) {
          print('Exception _checkStatus: ' + e.toString());
          await FirebaseService.logout();
          Get.offAll(() => Common.registerScreen??Container());
        } finally {
          //MyApp.hideWatting();
        }
      } else
        isOnline = false;
    } on SocketException catch (_) {
      isOnline = false;
    }
    print('isonline$isOnline');
    Get.put(ConnectActivityController()).setIsOnline(isOnline);
  }

  void disposeStream() => controller.close();
}

 
class GetTo{
  static checkInterNet(dynamic page,BuildContext context){
    ConnectActivityController controller = Get.find<ConnectActivityController>();
    if(controller.isOnline){
      Get.to(page);
    }else{
      showDialog(
          context: context,
          builder: (BuildContext context) { 
            return Common.dialogNotificationInternet ??Container();
          });
    }
  }
}
